Utility Package
=======================

Submodules
----------

JSON Module
------------------------------------

.. automodule:: tmtccmd.util.json
   :members:
   :undoc-members:
   :show-inheritance:

Object ID Module
----------------------

.. automodule:: tmtccmd.util.obj_id
   :members:
   :undoc-members:
   :show-inheritance:

Exit Module
------------------------------------

.. automodule:: tmtccmd.util.exit
   :members:
   :undoc-members:
   :show-inheritance:

Hamming-Code Module
----------------------------------

.. automodule:: tmtccmd.util.hammingcode
   :members:
   :undoc-members:
   :show-inheritance:

TMTC Printer (FSFW) Module
------------------------------------

.. automodule:: tmtccmd.fsfw.tmtc_printer
   :members:
   :undoc-members:
   :show-inheritance:

Configuration Utility Module
---------------------------------

.. automodule:: tmtccmd.util.conf_util
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: tmtccmd.util
   :members:
   :undoc-members:
   :show-inheritance:

Countdown Module
------------------

The countdown module was moved to the `spacepackets` library. Use the
:py:mod:`spacepackets.countdown` module.

Sequence Count Module
--------------------------

The sequence count module was moved to the `spacepackets` library. Use the
:py:mod:`spacepackets.seqcount` module.

.. _`spacepackets`: https://github.com/us-irs/spacepackets-py
